/**
  *  \file planetscentral/dbclient/dblist.h
  */
#ifndef C2SERVER_PLANETSCENTRAL_DBCLIENT_DBLIST_H
#define C2SERVER_PLANETSCENTRAL_DBCLIENT_DBLIST_H

#include "planetscentral/dbclient/dbkey.h"
#include "planetscentral/dbclient/connection.h"
#include "planetscentral/dbclient/dbsort.h"

class DbList : public DbKey {
 public:
    DbList(DbClient& client, string_t key);

    int32_t size();
    bool    empty();
    void trimToRange(int32_t start, int32_t end);
    DbSort sort();
};

class DbIntList : public DbList {
 public:
    DbIntList(DbClient& client, string_t key);
    int32_t operator[](int32_t index);
    int32_t popFront();
    int32_t pushFront(int32_t value);
    int32_t popBack();
    int32_t pushBack(int32_t value);
    void set(int32_t index, int32_t value);
    int32_t removeValue(int32_t value, int32_t count);
    int32_t transferElement(DbIntList& other);
    void getAll(IntList_t& list);
    //LRANGE key start end    list<string>                            list[key].slice(start, end) // both inclusive, negative to count from end
};

class DbStringList : public DbList {
 public:
    DbStringList(DbClient& client, string_t key);
    string_t operator[](int32_t index);
    string_t popFront();
    string_t pushFront(string_t value);
    string_t popBack();
    string_t pushBack(string_t value);
    void set(int32_t index, string_t value);
    int32_t removeValue(string_t value, int32_t count);
    string_t transferElement(DbStringList& other);
    void getAll(StringList_t& list);
    //LRANGE key start end    list<string>                            list[key].slice(start, end) // both inclusive, negative to count from end
};

//BLPOP k1 k2... timeout  list<string>-or-nil, key and value      LPOP k1, k2, ... whichever is available first
//BRPOP k1 k2... timeout  list<string>-or-nil, key and value      RPOP k1, k2, ... whichever is available first
//BRPOPLPUSH k1 k2 to     string                                  blocking RPOPLPUSH

#endif
