/**
  *  \file planetscentral/dbclient/dbstring.cc
  */

#include "planetscentral/dbclient/dbstring.h"
#include "planetscentral/dbclient/dbclient.h"

DbString::DbString(DbClient& client, string_t s)
    : DbKey(client, s)
{ }

void
DbString::append(const string_t& what)
{
    client.callVoid(DbRequest().withString("APPEND").withString(key).withString(what));
}

string_t
DbString::get()
{
    return client.callString(DbRequest().withString("GET").withString(key));
}

string_t
DbString::substr(std::size_t start, std::size_t length)
{
    if (length > 0) {
        return client.callString(DbRequest().withString("GETRANGE").withString(key).withInt(start).withInt(start+length-1));
    } else {
        return string_t();
    }
}

string_t
DbString::replaceBy(const string_t& newValue)
{
    return client.callString(DbRequest().withString("GETSET").withString(key).withString(newValue));
}

void
DbString::set(const string_t& newValue)
{
    client.callVoid(DbRequest().withString("SET").withString(key).withString(newValue));
}

bool
DbString::setNew(const string_t& newValue)
{
    return client.callInt(DbRequest().withString("SETNX").withString(key).withString(newValue));
}
